@@ -28,7 +28,25 @@ def write_solution(model, solution, threshold, filename='imat_sol.csv'):
     return solution, solution_binary
 
 
-def read_solution(filename, model=None):
+def read_solution(filename, model=None, solution_index=0):
+    """
+    Reads a solution from a .csv file. If the provided file is a binary solutions file
+    (as output by enumeration methods), the solution number solution_index will be read
+
+    Parameters
+    ----------
+    filename: str
+        name of the file containing the solution
+    model: cobra.Model
+        optional unless the filename points to a binary solution file without reaction IDs
+    solution_index: int
+        defines which solution will be read from the binary solution file
+
+    Returns
+    -------
+    solution: cobra.Solution
+    sol_bin: numpy.array
+    """
     binary = True
     with open(filename, 'r') as f:
         reader = f.read().split('\n')
@@ -39,11 +57,11 @@ def read_solution(filename, model=None):
             objective_value = float(reader[-2].split()[-1])
             status = reader[-1].split()[-1]
     if binary:
-        fluxes = pd.read_csv(filename, index_col=0).iloc[0]
+        fluxes = pd.read_csv(filename, index_col=0).iloc[solution_index]
         if model is not None:
             fluxes.index = [rxn.id for rxn in model.reactions]
         else:
-            warn('A model is necessary for setting the reaction IDs in a binary solution.'
+            warn('A model is necessary for setting the reaction IDs in a binary solution. '
                  'Disregard this warning if the columns of the binary solution are already reaction IDs')
         sol_bin = np.array(fluxes.values)
         objective_value = 0.
@@ -56,42 +74,34 @@ def read_solution(filename, model=None):
     return solution, sol_bin
 
 
-def combine_binary_solutions(sol_path):
-    solutions = Path(sol_path).glob('*solutions.csv')
-    sollist = []
-    for sol in solutions:
-        sollist.append(pd.read_csv(sol, index_col=0))
-    fullsol = pd.concat(sollist, ignore_index=True)
-    uniquesol = fullsol.drop_duplicates()
-    print('There are %i unique solutions and %i duplicates.' % (len(uniquesol), len(fullsol) - len(uniquesol)))
-    uniquesol.to_csv(sol_path+'combined_solutions.csv')
-    return uniquesol
-
-
-def compile_solutions(solutions, out_path='compiled_solutions', model=None, threshold=None):
+def compile_solutions(solutions, out_path='compiled_solutions', solution_pattern='*.csv', model=None, threshold=None):
     """
     Compiles individual solution files into one binary solution DataFrame
+
     Parameters
     ----------
     solutions: list or str
-        if list: either a list of solution files in .csv format
-                 or a list of Solution objects
-                 or a list of binary solution arrays
-        if str: a folder in which all .csv files are solutions
+        If list, must contain either solution files in .csv format, or Solution objects, or binary solution arrays. -
+        If str, must be a folder in which the solution files math the sollution_pattern parameter
     out_path: str
         path to which the combined solutions will be saved
+    solution_pattern: str
+        If reading solutions from a folder, this is the pattern which will be used to recognize solution files
     model: cobrapy Model
-        necessary if the solutions parameter is a list of Solution objects
+        required  if the solutions parameter is a list of Solution objects
     threshold: float
         required if the solutions parameter is a list of Solution objects
+
     Returns
     -------
     sol_frame: pandas DataFrame containg binary solutions
     """
     if model is not None:
         tol = model.solver.configuration.tolerances.feasibility
+    else:
+        tol = None
     if isinstance(solutions, str):
-        sol_paths = [str(x) for x in Path(solutions).glob('*.csv')]
+        sol_paths = [str(x) for x in Path(solutions).glob(solution_pattern)]
     else:
         sol_paths = solutions
     sols = []
@@ -111,7 +121,7 @@ def compile_solutions(solutions, out_path='compiled_solutions', model=None, thre
             warn('Unrecognized type %s for solution %s' % (type(s), s))
         if binsol is not None:
             sols.append(binsol)
-    sol_frame = pd.DataFrame(sols)
+    sol_frame = pd.DataFrame(sols).drop_duplicates(ignore_index=True)
     sol_frame.to_csv(out_path+'.csv')
     return sol_frame
 
@@ -172,7 +182,12 @@ def plot_pca(solution_path, rxn_enum_solutions=None, save=True, save_name=''):
     return pca
 
 
-if __name__ == '__main__':
+def main():
+    """
+    This function is called when you run this script from the commandline.
+    It plots a 2-dimensional PCA of enumeration solutions and saves as png
+    Use --help to see commandline parameters
+    """
     description = 'Plots a 2-dimensional PCA of enumeration solutions and saves as png'
     parser = argparse.ArgumentParser(description=description, formatter_class=argparse.RawTextHelpFormatter)
     parser.add_argument('-s', '--solutions', help='csv file containing diversity-enumeration solutions')
@@ -182,3 +197,8 @@ if __name__ == '__main__':
     args = parser.parse_args()
 
     pca = plot_pca(args.solutions, rxn_enum_solutions=args.rxn_solutions, save_name=args.out_path)
+    return True
+
+
+if __name__ == '__main__':
+    main()
